diff include/SDL_video.h @ 1669:9857d21967bb SDL-1.3

The test programs compile again. The dummy video driver is partially functional now.
author Sam Lantinga <slouken@libsdl.org>
date Mon, 29 May 2006 05:08:33 +0000
parents 4da1ee79c9af
children eef792d31de8
line wrap: on
line diff
--- a/include/SDL_video.h	Mon May 29 04:04:35 2006 +0000
+++ b/include/SDL_video.h	Mon May 29 05:08:33 2006 +0000
@@ -126,22 +126,29 @@
                          struct SDL_Surface * dst, SDL_Rect * dstrect);
 
 
 /* Useful for determining the video hardware capabilities */
 typedef struct SDL_VideoInfo
 {
-    Uint32 hw_available:1;      /* Flag: Can you create hardware surfaces? */
-    Uint32 wm_available:1;      /* Flag: Can you talk to a window manager? */
+    Uint32 hw_available:1;  /**< Flag: Can you create hardware surfaces? */
+    Uint32 wm_available:1;  /**< Flag: Can you talk to a window manager? */
     Uint32 UnusedBits1:6;
     Uint32 UnusedBits2:1;
-    Uint32 blit_hw:1;           /* Flag: Accelerated blits HW --> HW */
-    Uint32 blit_hw_CC:1;        /* Flag: Accelerated blits with Colorkey */
-    Uint32 blit_hw_A:1;         /* Flag: Accelerated blits with Alpha */
-    Uint32 blit_sw:1;           /* Flag: Accelerated blits SW --> HW */
-    Uint32 blit_sw_CC:1;        /* Flag: Accelerated blits with Colorkey */
-    Uint32 blit_sw_A:1;         /* Flag: Accelerated blits with Alpha */
-    Uint32 blit_fill:1;         /* Flag: Accelerated color fill */
+    Uint32 blit_hw:1;       /**< Flag: Accelerated blits HW --> HW */
+    Uint32 blit_hw_CC:1;    /**< Flag: Accelerated blits with Colorkey */
+    Uint32 blit_hw_A:1;     /**< Flag: Accelerated blits with Alpha */
+    Uint32 blit_sw:1;       /**< Flag: Accelerated blits SW --> HW */
+    Uint32 blit_sw_CC:1;    /**< Flag: Accelerated blits with Colorkey */
+    Uint32 blit_sw_A:1;     /**< Flag: Accelerated blits with Alpha */
+    Uint32 blit_fill:1;     /**< Flag: Accelerated color fill */
     Uint32 UnusedBits3:16;
     Uint32 video_mem;           /* The total amount of video memory (in K) */
+
+    /* Here for backwards compatibility */
+    SDL_PixelFormat *vfmt;
 } SDL_VideoInfo;
 
 /**
@@ -126,22 +126,29 @@
 
 
-/* Useful for determining the video hardware capabilities */
+/**
+ * \struct SDL_VideoInfo
+ *
+ * \brief Useful for determining the video hardware capabilities
+ */
 typedef struct SDL_VideoInfo
 {